@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Convert notes and chords to Roman numeral notation
 
-our $VERSION = '0.1200';
+our $VERSION = '0.1300';
 
 use List::MoreUtils qw/ any first_index /;
 use Moo;
@@ -102,7 +102,7 @@ sub parse {
     print "NOTES: @notes\n" if $self->verbose;
 
     # Convert a diminished chord
-    $chord =~ s/dim/o/; # TODO: Handle U+00F8 too
+    $chord =~ s/(?:dim|ø)/o/;
 
     # Get just the note part of the chord name
     ( my $note = $chord ) =~ s/^($note_re).*$/$1/;
@@ -137,11 +137,15 @@ sub parse {
     if ( $decorator =~ /maj/i || $decorator =~ /min/i ) {
         $decorator = lc $decorator;
     }
+    elsif ( $decorator =~ /△/ ) {
+        $decorator =~ s/△/maj/;
+    }
     else {
         # Drop the minor and major part of the chord name
         $decorator =~ s/M//i;
         $decorator =~ s/-//i;
     }
+    print "DECO: $decorator\n" if $self->verbose;
 
     # Handle these unfortunate edge cases
     $roman =~ s/#I\b/bII/;
@@ -284,7 +288,7 @@ Music::ToRoman - Convert notes and chords to Roman numeral notation
 
 =head1 VERSION
 
-version 0.1200
+version 0.1300
 
 =head1 SYNOPSIS
 
@@ -298,6 +302,7 @@ version 0.1200
   my $roman = $mtr->parse('Am');  # i (minor)
   $roman = $mtr->parse('Bo');     # iio (diminished)
   $roman = $mtr->parse('Bdim');   # iio (diminished)
+  $roman = $mtr->parse('Bø');     # iio (diminished)
   $roman = $mtr->parse('Bb');     # bII (flat-two major)
   $roman = $mtr->parse('CM');     # III (major)
   $roman = $mtr->parse('C');      # III (major)
@@ -305,6 +310,7 @@ version 0.1200
   $roman = $mtr->parse('Cm9/Bb'); # iii9/bii (minor ninth with flat-two bass)
   $roman = $mtr->parse('D sus4'); # IV sus4 (major suspended)
   $roman = $mtr->parse('DMaj7');  # IV maj7 (major seventh)
+  $roman = $mtr->parse('D△7');    # IV maj7 (major seventh)
   $roman = $mtr->parse('E7');     # V7 (dominant seventh)
   $roman = $mtr->parse('Em7');    # v7 (minor seventh)
   $roman = $mtr->parse('Fmin7');  # vi min7 (minor seventh)
@@ -376,7 +382,7 @@ C<ionian>).
 =head2 chords
 
 Are we given chords to parse with major (C<M>) or minor
-(C<m>/C<o>/C<dim>) designations?
+(C<m>/C<o>/C<dim>/C<ø>) designations?
 
 Default: C<1>
 
@@ -422,10 +428,6 @@ A diminished chord may be given as either C<o> or C<dim>.
 If the B<chords> attribute is set to C<0>, the B<scale_name> is used
 to figure out the correct Roman numeral representation.
 
-If the B<scale_note> is a double-accidental, and the B<scale_name> is
-not C<major> (or C<ionian>), the B<major_tonic> must be set in the
-constructor.
-
 =head1 SEE ALSO
 
 L<List::MoreUtils>
